@@ -7,9 +7,10 @@ use std::{io::Write, time::Duration};
 use std::{net::SocketAddr, str::FromStr};
 use structopt::StructOpt;
 use tabwriter::TabWriter;
-use themelio_stf::{
-    melvm::{Address, Covenant},
-    CoinData, CoinID, Denom, NetID, PoolKey, StakeDoc, Transaction, TxHash, TxKind, STAKE_EPOCH,
+use themelio_stf::{melvm::Covenant, PoolKey};
+use themelio_structs::{
+    Address, CoinData, CoinID, CoinValue, Denom, NetID, StakeDoc, Transaction, TxHash, TxKind,
+    STAKE_EPOCH,
 };
 use tmelcrypt::{Ed25519PK, HashVal};
 mod autoswap;
@@ -110,6 +111,11 @@ enum Args {
         #[structopt(flatten)]
         wargs: WalletArgs,
     },
+    /// Checks a wallet to make sure it's up to day.
+    Check {
+        #[structopt(flatten)]
+        wargs: WalletArgs,
+    },
     /// Checks a pool.
     Pool {
         #[structopt(flatten)]
@@ -443,7 +449,7 @@ fn main() -> http_types::Result<()> {
                 } else {
                     max_value
                 };
-                let value = value.unwrap_or(max_value.into());
+                let value = value.unwrap_or_else(|| max_value.into());
                 let pool_key = PoolKey::new(from, to);
                 let to_send = wallet
                     .prepare_transaction(
@@ -463,9 +469,9 @@ fn main() -> http_types::Result<()> {
                 writeln!(twriter, "{}", "SWAPPING".bold())?;
                 writeln!(
                     twriter,
-                    "From:\t{} µ{}",
-                    value.to_string().bold().bright_green(),
-                    from.to_string()
+                    "From:\t{} {}",
+                    CoinValue(value).to_string().bold().bright_green(),
+                    from
                 )?;
                 let pool_state = wargs
                     .common
@@ -479,9 +485,9 @@ fn main() -> http_types::Result<()> {
                 };
                 writeln!(
                     twriter,
-                    "To:\t{} µ{} (approximate)",
-                    to_value.to_string().bold().yellow(),
-                    to.to_string()
+                    "To:\t{} {} (approximate)",
+                    CoinValue(to_value).to_string().bold().yellow(),
+                    to
                 )?;
                 twriter.flush()?;
                 proceed_prompt(&mut stdin).await?;
@@ -491,6 +497,10 @@ fn main() -> http_types::Result<()> {
                     wait_tx(&wallet, txhash).await?
                 }
             }
+            Args::Check { wargs } => {
+                let wallet = wargs.wallet().await?;
+                wallet.check().await?;
+            }
         }
         twriter.flush()?;
         Ok(())
@@ -512,21 +522,16 @@ async fn send_tx(
             output.covhash.to_string().bright_blue(),
             output.value,
             match output.denom {
-                Denom::Mel => "µMEL",
-                Denom::Sym => "µSYM",
-                Denom::NomDosc => "µnomDOSC",
+                Denom::Mel => "MEL",
+                Denom::Sym => "SYM",
+                Denom::Erg => "ERG",
                 Denom::Custom(_) => "(custom token)",
                 Denom::NewCoin => "(new token type)",
             },
             hex::encode(&output.additional_data)
         )?;
     }
-    writeln!(
-        twriter,
-        "{}\t{} µMEL",
-        " (network fees)".yellow(),
-        tx.fee.to_string()
-    )?;
+    writeln!(twriter, "{}\t{} MEL", " (network fees)".yellow(), tx.fee)?;
     twriter.flush()?;
     proceed_prompt(&mut stdin).await?;
     let txhash = wallet.send_tx(tx).await?;
@@ -572,13 +577,13 @@ fn write_wallet_summary(
     writeln!(
         out,
         "Balance:\t{}",
-        format!("{}\tµMEL", summary.total_micromel)
+        format!("{}\tMEL", summary.total_micromel)
     )?;
     for (k, v) in summary.detailed_balance.iter() {
         let denom = match k.as_str() {
             "6d" => continue,
-            "73" => "µSYM",
-            "64" => "µnomDOSC",
+            "73" => "SYM",
+            "64" => "ERG",
             v => v,
         };
         writeln!(out, "\t{}\t{}", v, denom)?;
@@ -586,7 +591,7 @@ fn write_wallet_summary(
     writeln!(
         out,
         "Staked:\t{}",
-        format!("{}\tµSYM", summary.staked_microsym)
+        format!("{}\tSYM", summary.staked_microsym)
     )?;
     Ok(())
 }
